﻿Imports System.IO

Public Class MainForm

    Private m_strOptionValue As String
    Private m_bFirstLoadCompleted As Boolean

    Public Property OptionValue() As String
        Get
            Return m_strOptionValue
        End Get
        Set(ByVal value As String)
            m_strOptionValue = value
        End Set
    End Property

    Private Sub MainForm_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        smartForm1.MainForm = Me

        smartLabel1.Text = "2022-01-01"
        smartLabel2.Text = "2022-12-31"
        smartComboBox1.ItemList.AddItem("IEC1000-Series")
        smartComboBox1.SelectItemIndex = 0

        ' SmartUpdate의 초기값을 설정
        UpdateInit()

        ' 업데이트 설정을 불러오기
        ReadUpdateOption()

        ' FormLoad가 완료되면 플래그 설정
        m_bFirstLoadCompleted = True
    End Sub

    Private Sub MainForm_Closing(ByVal sender As System.Object, ByVal e As System.ComponentModel.CancelEventArgs) Handles MyBase.Closing
        smartTimer1.Stop()
        smartMemory1.ExtStorageDetectionStop()
        smartMemory1.Release()
    End Sub

    Private Sub btnUpdateSetting_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnUpdateSetting.Click
        ' 설정창을 다이얼로그 방식으로 열기
        Dim dr As DialogResult = smartForm1.ShowDialog(GetType(SettingForm))

        ' 설정창에서 적용 버튼이 눌렸을 때
        If dr = DialogResult.OK Then
            Dim di As DirectoryInfo = New DirectoryInfo("Flash Disk\UpdateOption")
            If di.Exists = False Then
                di.Create()
            End If

            ' ini 형식 파일로 업데이트 설정 값 저장
            SmartX.SmartFile.WritePrivateProfileString("UpdateOption", "Option", m_strOptionValue, "Flash Disk\UpdateOption\Option.ini")
            ' 업데이트 설정값을 적용
            ReadUpdateOption()
        End If
    End Sub

    Private Sub smartTimer1_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles smartTimer1.Tick
        ' 사용자가 지정한 Interval의 시간만큼 지났을 때
        ' 외부저장장치 연결 감지를 종료
        smartMemory1.ExtStorageDetectionStop()
        ' 타이머 종료
        smartTimer1.Stop()
    End Sub

    Private Sub smartMemory1_EvtExternalStorageAttached(ByVal bAttached As System.Boolean, ByVal strDeviceName As System.String) Handles smartMemory1.EvtExternalStorageAttached
        ' 외부저장장치가 연결된 경우
        If bAttached = True Then

            If m_strOptionValue = "FormLoad" Then
                smartMemory1.ExtStorageDetectionStop()
            End If

            If smartTimer1.IsStart = True Then
                smartTimer1.Stop()
            End If

            ' 업데이트 진행
            UpdateCheckApply(strDeviceName)
        End If
    End Sub

    Private Sub UpdateInit()
        smartUpdate1.TitleText = "SmartUpdate Test"
        smartUpdate1.TitleTextColor = Color.White
        smartUpdate1.CompanyText = "HNS"
        smartUpdate1.CompanyTextColor = Color.White
        smartUpdate1.MessageText = "응용 프로그램을 업데이트 중..."
        smartUpdate1.MessageTextColor = Color.Black
    End Sub

    Private Sub ReadUpdateOption()
        smartMemory1.ExtStorageDetectionStop()

        ' ini 형식 파일로부터 업데이트 설정에 대한 값을 읽기
        SmartX.SmartFile.GetPrivateProfileString("UpdateOption", "Option", "Failed", m_strOptionValue, "Flash Disk\UpdateOption\Option.ini")

        ' 읽어온 설정값에 따라 업데이트 방법을 변경
        ' "FormLoad" : 프로그램이 실행될 때 업데이트 처리
        ' "Always" : 항상 외부저장장치의 인식에 따른 업데이트 처리
        If m_strOptionValue = "FormLoad" Then
            ' 처음 폼이 로드되었을 때만 진행
            If m_bFirstLoadCompleted = False Then
                ' 외부저장장치의 연결 감지를 시작
                smartMemory1.ExtStorageDetectionStart()
                ' Interval값을 조절하여 FormLoad 이후 언제까지 외부저장장치 감지를 활성화할지 정함 (단위 : ms)
                smartTimer1.Interval = 15000
                smartTimer1.Start()
            End If
        ElseIf m_strOptionValue = "Always" Then
            ' 외부저장장치의 연결 감지를 시작
            smartMemory1.ExtStorageDetectionStart()
        Else
            SmartX.SmartMessageBox.Show("잘못된 업데이트 설정값입니다!")
        End If
    End Sub

    Private Sub UpdateCheckApply(ByVal strDeviceName As String)
        ' 업데이트 파일이 있는 디렉터리가 존재하는지 검사
        Dim bExist As Boolean = System.IO.Directory.Exists(strDeviceName & "\UpdateFiles")
        If bExist = True Then
            ' 업데이트 파일이 위치한 경로 설정
            smartUpdate1.FromFilePath = strDeviceName & "\UpdateFiles"
            ' 업데이트 대상 경로 설정
            smartUpdate1.ToFilePath = "Flash Disk\Run"
            ' 업데이트 후 프로그램 재시작
            smartUpdate1.Restart = SmartX.SmartUpdate.RESTARTFLAG.AUTORUNEXECUTE

            ' 응용 프로그램이 종료된 후 업데이트 모듈이 업데이트를 시작하기까지의 지연 시간을 설정함
            ' 응용 프로그램의 용량 등(프로그램 복잡도)에 따라서 종료되는 지연 시간을 감안하여
            ' Interval을 충분한 값으로 설정하시기 바랍니다. (단위 : ms)
            smartUpdate1.UpdateStartInterval = 3000

            ' 업데이트 파일을 확인하며 업데이트할 파일이 있을 경우 업데이트 시작
            ' 리턴값 : 업데이트할 파일이 있는 경우 true, 업데이트할 파일이 없는 경우 false
            If smartUpdate1.UpdateCheck() = True Then
                Dim dr As DialogResult = SmartX.SmartMessageBox.Show("업데이트를 시작 하시겠습니까?", "업데이트 시작", MessageBoxButtons.YesNo, MessageBoxIcon.Question)

                If dr = DialogResult.Yes Then
                    smartUpdate1.Start()
                    smartForm1.Close()
                End If
            End If
        End If
    End Sub
End Class
